@@ -1,19 +1,13 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+    SPDX-FileCopyrightText: 2012-2020 Andrius Štikonas <andrius@stikonas.eu
+    SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2016 Chantara Tith <tith.chantara@gmail.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "gui/partresizerwidget.h"
 #include "gui/partwidget.h"
@@ -278,8 +272,8 @@ bool PartResizerWidget::movePartition(qint64 newFirstSector)
 
     updatePositions();
 
-    emit firstSectorChanged(partition().firstSector());
-    emit lastSectorChanged(partition().lastSector());
+    Q_EMIT firstSectorChanged(partition().firstSector());
+    Q_EMIT lastSectorChanged(partition().lastSector());
 
     return true;
 }
@@ -335,7 +329,7 @@ bool PartResizerWidget::updateFirstSector(qint64 newFirstSector)
 
         updatePositions();
 
-        emit firstSectorChanged(partition().firstSector());
+        Q_EMIT firstSectorChanged(partition().firstSector());
 
         return true;
     }
@@ -416,7 +410,7 @@ bool PartResizerWidget::updateLastSector(qint64 newLastSector)
         resizeLogicals(0, deltaLast);
         updatePositions();
 
-        emit lastSectorChanged(partition().lastSector());
+        Q_EMIT lastSectorChanged(partition().lastSector());
 
         return true;
     }
